**8. Glossary**
===============

.. confval:: Generation Mix

    The combination of the various fuels used to generate electricity in a given geographic region.

.. confval:: Grid Dispatch

    The process by which transmission system operators decide which power plants and generation facilities to deploy to meet current electricity demand.

.. confval:: Unit Commitment

    Determines when and which generating units to start-up and shut-down.

.. confval:: Economic Dispatch

    Establishes the amount of power supplied by each unit.

.. confval:: Susceptance

    Represents how much circuit is susceptible to conducting a changing current or simply how much circuit allows the changing current.

.. confval:: Derating Factor

    A reduction factor applied to the nominal capacity or rating of a component, such as a generator, transformer, or transmission line, to account for operating conditions or  constraints that may limit its performance such as temperature, humidity, altitude, loading, and system configuration. These deviations can affect the performance and capability of power system components.

.. confval:: N-1 Criterion

    A reliability criterion used in power systems to ensure grid reliability by assessing the system's ability to  withstand the loss of a single component without causing a widespread blackout or cascading failures.

.. confval:: Spinning Reserve

    The excess generating capacity that is immediately available and synchronized to the grid (but is not currently generating energy) to meet unexpected increases in electricity demand or compensate for sudden generator or transmission line outages.
